@@ -52,7 +52,7 @@ def topic_directories(path) -> (list, list):
                             method_listing[method] = {isograd: full_path_data}
                     else:
                         method_listing[method] = {isograd: full_path_data}
-                        
+
                     if temperature_listing.get(isograd):
                         temperature_listing[isograd].append(temperature)
                     else:
@@ -64,11 +64,14 @@ def topic_directories(path) -> (list, list):
                     else:
                         directory_listing[t] = {temperature: {method: full_path_data}}
                     if method_listing.get(method):
-                        method_listing[method][temperature].extend(full_path_data)
+                        if method_listing[method].get(temperature):
+                            method_listing[method][temperature].extend(full_path_data)
+                        else:
+                            method_listing[method] = {temperature: full_path_data}
                     else:
                         method_listing[method] = {temperature: full_path_data}
 
-    for k, v in temperature_listing:
+    for k, v in temperature_listing.items():
         temperature_listing[k] = list(set(v))
     return directory_listing, method_listing, temperature_listing
 
